@@ -3,8 +3,8 @@ import datetime
 from htsql import HTSQL
 from celery.task import task
 
-from report_handler import ReportHandler
-from formatter import CSVFormatter
+from async_reports.report_handler import ReportHandler
+from async_reports.formatter import CSVFormatter
 
 from django.conf import settings
 from django.forms import Form
